# <img src="https://raw.githubusercontent.com/nimaid/pixelgreat-gui/main/pixelgreat_gui/resources/icon.png?raw=true" height="20px" alt="Pixelgreat"/> Pixelgreat GUI
### A GUI for [Pixelgreat: A highly realistic RGB pixel filter.](https://pypi.org/project/pixelgreat/)

<p align="center"><img src="https://raw.githubusercontent.com/nimaid/pixelgreat-gui/main/docs/example.png?raw=true" width="800px" alt="Screenshot of the program"/></p>

## Command Line Usage
After installing the module, run `python -m pixelgreat-gui`.

